from distutils.core import setup
 
setup(
    name='SomeToolspbc',  # 对外模块的名字
    version='2.0.1',  # 版本号
    description='some tools',  # 描述
    author='pbcat2022',  # 作者
    author_email='yuyao_100804@outlook.com',
    packages=['SomeToolspbc']
)